@@ -75,7 +75,7 @@ sub new {
         Name => $name,
     }, $type;
 
-    my $inccode = join '',map {$_->get_incregisters();} (values %{$this->{ParObjs}});
+    my $inccode = join '',map {$_->get_incregisters();} (sort values %{$this->{ParObjs}});
 
     # First, separate the code into an array of C fragments (strings),
     # variable references (strings starting with $) and
@@ -165,7 +165,7 @@ sub new {
 
     # Then, in this form, put it together what we want the code to actually do.
     print "SIZEPRIVS: ",(join ',',%$sizeprivs),"\n" if $::PP_VERBOSE;
-    $this->{Code} = "{".(join '',values %$sizeprivs).
+    $this->{Code} = "{".(join '',sort values %$sizeprivs).
        $coderef->get_str($this,[])
        ."}";
     $this->{Code};
@@ -250,8 +250,10 @@ sub get_str {
     my $good = $this->[0];
     my $bad  = $this->[1];
 
-    my $str = "if ( \$PRIV(bvalflag) ) { PDL_COMMENT(\"** do 'bad' Code **\")\n";
+    my $str = PDL::PP::pp_line_numbers(__LINE__, "if ( \$PRIV(bvalflag) ) { PDL_COMMENT(\"** do 'bad' Code **\")\n");
+    $str .= "\n#define PDL_BAD_CODE\n";
     $str .= $bad->get_str($parent,$context);
+    $str .= "\n#undef PDL_BAD_CODE\n";
     $str .= "} else { PDL_COMMENT(\"** else do 'good' Code **\")\n";
     $str .= $good->get_str($parent,$context);
     $str .= "}\n";
@@ -288,7 +290,7 @@ sub myprelude { my($this,$parent,$context) = @_;
 			for($_=0; $_<(__$i->[0]_size); $_++) {";
 		$i;
 	} @{$this->[0]};
-	return $text;
+	return PDL::PP::pp_line_numbers(__LINE__, $text);
 }
 sub mypostlude { my($this,$parent,$context) = @_;
 	splice @$context, - ($#{$this->[0]}+1);
@@ -371,12 +373,12 @@ sub myitem {
 				"#define THISIS$this->[1]_$item->[3](a) a\n";
     }
 
-    return "\t} break; case $item->[0]: {\n".
+    return PDL::PP::pp_line_numbers(__LINE__, "\t} break; case $item->[0]: {\n".
 	$thisis_loop .
 	    (join '',map{
 		# print "DAPAT: '$_'\n";
 		$parent->{ParObjs}{$_}->get_xsdatapdecl($item->[1]);
-	    } (@{$this->[2]})) ;
+	    } (@{$this->[2]})));
 }
 
 sub mypostlude {
@@ -411,13 +413,13 @@ sub myoffs { return 0; }
 sub myprelude {my($this,$parent,$context) = @_;
  my $no;
  my ($ord,$pdls) = $parent->get_pdls();
-'	PDL_COMMENT("THREADLOOPBEGIN")
+PDL::PP::pp_line_numbers(__LINE__, '	PDL_COMMENT("THREADLOOPBEGIN")
  if(PDL->startthreadloop(&($PRIV(__pdlthread)),$PRIV(vtable)->readdata,
  	__privtrans))) return;
    do {
  '.(join '',map {"${_}_datap += \$PRIV(__pdlthread).offs[".(0+$no++)."];\n"}
  		@$ord).'
-';
+');
 }
 
 sub mypostlude {my($this,$parent,$context) = @_;
@@ -455,52 +457,47 @@ sub myprelude {
     my $funcName = "readdata";
     $funcName = "writebackdata" if( $backcode );
 
-
-    my $no; my $no2=-1; my $no3=-1;
     my ($ord,$pdls) = $parent->get_pdls();
 
-'	PDL_COMMENT("THREADLOOPBEGIN")
- if(PDL->startthreadloop(&($PRIV(__pdlthread)),$PRIV(vtable)->'.$funcName.',
- 	__tr)) return;
-   do { register PDL_Indx __tind1=0,__tind2=0;
-        register PDL_Indx __tnpdls = $PRIV(__pdlthread).npdls;
-      register PDL_Indx __tdims1 = $PRIV(__pdlthread.dims[1]);
-      register PDL_Indx __tdims0 = $PRIV(__pdlthread.dims[0]);
-      register PDL_Indx *__offsp = PDL->get_threadoffsp(&$PRIV(__pdlthread));
- '.(join '',map {$no2++;
-            "register PDL_Indx __tinc0_".($no2)." = \$PRIV(__pdlthread).incs[$no2];"}
-	     @$ord).
-   (join '',map {$no3++;
-            "register PDL_Indx __tinc1_".($no3)." = \$PRIV(__pdlthread).incs[__tnpdls+$no3];"}
-	     @$ord).
-   (join '',map {"${_}_datap += __offsp[".(0+$no++)."];\n"}
- 		@$ord).'
-	for(__tind2=0; __tind2<__tdims1 ; __tind2++) {
-	 for(__tind1=0; __tind1<__tdims0 ; __tind1++) {
-	  PDL_COMMENT("This is the tightest threadloop. Make sure inside is optimal.")
-';
+    PDL::PP::pp_line_numbers(__LINE__, join "\n	",
+	  '',
+	  'PDL_COMMENT("THREADLOOPBEGIN")',
+	  'if ( PDL->startthreadloop(&($PRIV(__pdlthread)),$PRIV(vtable)->'.$funcName.', __tr) ) return;
+           do { register PDL_Indx __tind1=0,__tind2=0;
+                register PDL_Indx __tnpdls = $PRIV(__pdlthread).npdls;
+                register PDL_Indx __tdims1 = $PRIV(__pdlthread.dims[1]);
+                register PDL_Indx __tdims0 = $PRIV(__pdlthread.dims[0]);
+                register PDL_Indx *__offsp = PDL->get_threadoffsp(&$PRIV(__pdlthread));',
+	  ( map { "register PDL_Indx __tinc0_${_} = \$PRIV(__pdlthread).incs[${_}];"} 0..$#{$ord}),
+	  ( map { "register PDL_Indx __tinc1_${_} = \$PRIV(__pdlthread).incs[__tnpdls+$_];"} 0.. $#{$ord}),
+	  ( map { $ord->[$_] ."_datap += __offsp[$_];"} 0..$#{$ord} ),
+	  'for( __tind2 = 0 ;
+                __tind2 < __tdims1 ;
+                __tind2++',
+	        ( map { "\t\t," . $ord->[$_] . "_datap += __tinc1_${_} - __tinc0_${_} * __tdims0"} 0..$#{$ord} ),
+             ')',
+	  '{
+	     for( __tind1 = 0 ;
+                  __tind1 < __tdims0 ;
+                  __tind1++',
+	          ( map { "\t\t," . $ord->[$_] . "_datap += __tinc0_${_}"} 0..$#{$ord}),
+	       ')',
+           '{  PDL_COMMENT("This is the tightest threadloop. Make sure inside is optimal.")'
+	);
 }
 
 # Should possibly fold out thread.dims[0] and [1].
 sub mypostlude {my($this,$parent,$context) = @_;
- my $no; my $no0; my $no1; my $no2; my $no3; my $no4; my $no5;
+
  my ($ord,$pdls) = $parent->get_pdls();
-'	PDL_COMMENT("THREADLOOPEND")
-	 '.(join '',map {"${_}_datap += __tinc0_".(0+$no0++).";\n"}
- 		@$ord).'
-	 } '
-	 .(join '',map {"${_}_datap += __tinc1_".(0+$no1++)."
-	     			     - __tinc0_".(0+$no2++)." *
-				       __tdims0;\n"}
- 		@$ord).'
-	} '.
-     (join '',map {"${_}_datap -= __tinc1_".(0+$no3++)." *
-     				  __tdims1;"}
- 		@$ord).'
- '.(join '',map {"${_}_datap -= __offsp[".(0+$no++)."];\n"}
- 		@$ord).'
-      } while(PDL->iterthreadloop(&$PRIV(__pdlthread),2));
- '
+ PDL::PP::pp_line_numbers(__LINE__, join "\n	",
+       '',
+       'PDL_COMMENT("THREADLOOPEND")',
+       '}',
+       '}',
+       ( map { $ord->[$_] . "_datap -= __tinc1_${_} * __tdims1 + __offsp[${_}];"} 0..$#{$ord} ),
+       '} while(PDL->iterthreadloop(&$PRIV(__pdlthread),2));'
+     )
 }
 
 # Simple subclass of ComplexThreadLoop to implement writeback code
