@@ -291,10 +291,10 @@ the end of the current paragraph is accepted, for example:
 
   =for example
 
-         ($x,$y) = $a->func(1,3);  # this is part of the accepted info
-         $x = func($a,0,1);        # this as well
+         ($x,$y) = $z->func(1,3);  # this is part of the accepted info
+         $x = func($z,0,1);        # this as well
 
-         $x = func($a,$b);         # but this isn't
+         $x = func($c,$d);         # but this isn't
 
 To make the resulting pod documentation also easily digestible for the
 existing pod filters (pod2man, pod2text, pod2html, etc) the actual
